package App::RedisTop;
use strict;
use warnings;
our $VERSION = '0.02';

1;
__END__

=head1 NAME

App::RedisTop - Redis resource statistics tool.

=head1 DESCRIPTION

Redis resource statistics tool.

=head1 AUTHOR

Tsuyoshi Torii E<lt>toritsuyo(at)cpan.orgE<gt>

=head1 SEE ALSO

L<redis-top>

=head1 THANKS TO

hirose31

fujiwara

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
